@@ -232,6 +232,7 @@ def interactive_loop(
             if command_lower == "exec":
                 if len(command) > 1:
                     try:
+                        logging.info("Running command: '{}'".format(command[1:]))
                         subprocess.run(command[1:])
                     except Exception as e:
                         print(e)
@@ -240,6 +241,7 @@ def interactive_loop(
             if command_lower == "cd":
                 if len(command) > 1:
                     try:
+                        logging.info("Attempting to cd to: '{}'".format(command[1]))
                         chdir(command[1])
                     except Exception as e:
                         print(e)
@@ -490,6 +492,8 @@ This is SoCo-CLI interactive mode. Interactive commands are as follows:
                     Aliases override existing actions and can contain
                     sequences of actions.
     'cd'         :  Change the working directory of the shell, e.g. 'cd ..'.
+                    Note that on Windows, backslashes must be doubled, e.g.:
+                    'cd C:\\'
     'docs'       :  Print a link to the documentation.
     'exec'       :  Run a shell command, e.g.: 'exec ls -l'.
     'exit'       :  Exit the shell.
